species.core package — species 0.1.2 documentation

# species.core package

## Submodules

## species.core.box module

Box module.

class `species.core.box.` `Box`

  Bases: `object`

  Text

  Returns: | None
  Return type: | NoneType

  `open_box`()

    Returns: | None
    Return type: | NoneType

class `species.core.box.` `ColorColorBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `ColorMagBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `IsochroneBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `ModelBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `ObjectBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `PhotometryBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `ResidualsBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `SamplesBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `SpectrumBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

class `species.core.box.` `SynphotBox`

  Bases: `species.core.box.Box`

  Text

  Returns: | None
  Return type: | NoneType

`species.core.box.` `create_box`(boxtype, **kwargs)

  Returns: |
  Return type: | species.core.box

## species.core.constants module

## species.core.setup module

Module for setting up species in the working folder.

class `species.core.setup.` `SpeciesInit`

  Bases: `object`

  Class for initiating species by creating the database and configuration file in case they are not present in the working folder, and creating the data folder for storage of input data.

  Returns: | None
  Return type: | NoneType

## Module contents